@@ -4,6 +4,7 @@
  *   SPDX-FileCopyrightText: 2017-2018 Adriaan de Groot <groot@kde.org>
  *   SPDX-FileCopyrightText: 2018 Raul Rodrigo Segura (raurodse)
  *   SPDX-FileCopyrightText: 2019 Camilo Higuita <milo.h@aol.com>
+ *   SPDX-FileCopyrightText: 2021 Anubhav Choudhary <ac.10edu@gmail.com>
  *   SPDX-License-Identifier: GPL-3.0-or-later
  *
  *   Calamares is Free Software: see the License-Identifier above.
@@ -22,11 +23,12 @@
 #include <QPixmap>
 #include <QSize>
 #include <QStringList>
+#include <QUrl>
 
 namespace YAML
 {
 class Node;
-}
+}  // namespace YAML
 
 namespace Calamares
 {
@@ -42,6 +44,7 @@ public:
      * e.g. *Branding::ProductName to get the string value for
      * the product name.
      */
+
     enum StringEntry
     {
         ProductName,
@@ -69,17 +72,32 @@ public:
     };
     Q_ENUM( ImageEntry )
 
+    /** @brief Names of style entries, for use in code
+     *
+     * These names are mapped to names in the branding.desc file through
+     * an internal table s_styleEntryStrings, which defines which names
+     * in `branding.desc` key *style* are used for which entry.
+     */
     enum StyleEntry : short
     {
         SidebarBackground,
         SidebarText,
-        SidebarTextSelect,
-        SidebarTextSelected = SidebarTextSelect,  // TODO:3.3:Remove SidebarTextSelect
-        SidebarTextHighlight,
-        SidebarBackgroundSelected = SidebarTextHighlight  // TODO:3.3:Remove SidebarTextHighlight
+        SidebarTextCurrent,
+        SidebarBackgroundCurrent,
     };
     Q_ENUM( StyleEntry )
 
+    /** @brief Supported log-upload servers.
+     *
+     * 'None' is here as a fallback.
+     */
+    enum UploadServerType : short
+    {
+        None,
+        Fiche
+    };
+    Q_ENUM( UploadServerType )
+
     /** @brief Setting for how much the main window may expand. */
     enum class WindowExpansion
     {
@@ -144,7 +162,7 @@ public:
 
     static Branding* instance();
 
-    explicit Branding( const QString& brandingFilePath, QObject* parent = nullptr );
+    explicit Branding( const QString& brandingFilePath, QObject* parent = nullptr, qreal devicePixelRatio = 1.0 );
 
     /** @brief Complete path of the branding descriptor file. */
     QString descriptorPath() const { return m_descriptorPath; }
@@ -184,6 +202,13 @@ public:
      */
     QPixmap image( const QString& name, const QSize& size ) const;
 
+    /** @brief Look up image with alternate names
+     *
+     * Calls image() for each name in the @p list and returns the first
+     * one that is non-null. May return a null pixmap if nothing is found.
+     */
+    QPixmap image( const QStringList& list, const QSize& size ) const;
+
     /** @brief Stylesheet to apply for this branding. May be empty.
      *
      * The file is loaded every time this function is called, so
@@ -207,6 +232,22 @@ public:
     ///@brief Which navigation flavor is configured
     PanelFlavor navigationFlavor() const { return m_navigationFlavor; }
 
+    /** @brief Upload server configuration
+     *
+     * This object has 3 items : the type (which may be none, in which case the URL
+     * is irrelevant and usually empty), the URL for the upload and the size limit of upload
+     * in bytes (for configuration value < 0, it serves -1, which stands for having no limit).
+     */
+    struct UploadServerInfo
+    {
+        UploadServerType type;
+        QUrl url;
+        qint64 size;
+
+        operator bool() const { return type != Calamares::Branding::UploadServerType::None && size != 0; }
+    };
+    UploadServerInfo uploadServer() const { return m_uploadServer; }
+
     /**
      * Creates a map called "branding" in the global storage, and inserts an
      * entry for each of the branding strings. This makes the branding
@@ -221,6 +262,12 @@ public slots:
     QString shortProductName() const { return string( ShortProductName ); }
     QString shortVersionedName() const { return string( ShortVersionedName ); }
 
+    /** @brief Map an enum-value to the entry from the *style* key.
+     *
+     * e.g. StyleEntry::SidebarTextCurrent maps to the corresponding
+     * *style* entry, which is (confusingly) named "sidebarTextSelect"
+     * in the branding file.
+     */
     QString styleString( StyleEntry styleEntry ) const;
     QString imagePath( ImageEntry imageEntry ) const;
 
@@ -232,13 +279,14 @@ private:
 
     static const QStringList s_stringEntryStrings;
     static const QStringList s_imageEntryStrings;
-    static const QStringList s_styleEntryStrings;
+    static const QStringList s_uploadServerStrings;
 
     QString m_descriptorPath;  // Path to descriptor (e.g. "/etc/calamares/default/branding.desc")
     QString m_componentName;  // Matches last part of full path to containing directory
     QMap< QString, QString > m_strings;
     QMap< QString, QString > m_images;
     QMap< QString, QString > m_style;
+    UploadServerInfo m_uploadServer;
 
     /* The slideshow can be done in one of two ways:
      *  - as a sequence of images
@@ -269,6 +317,8 @@ private:
     PanelFlavor m_navigationFlavor = PanelFlavor::Widget;
     PanelSide m_sidebarSide = PanelSide::Left;
     PanelSide m_navigationSide = PanelSide::Bottom;
+
+    qreal m_devicePixelRatio;
 };
 
 }  // namespace Calamares
