@@ -245,8 +245,6 @@ lookForFstabEntries( const QString& partitionPath )
 
     cDebug() << "Checking device" << partitionPath << "for fstab (fs=" << r.getOutput() << ')';
 
-    FstabEntryList fstabEntries;
-
     Calamares::Partition::TemporaryMount mount( partitionPath, QString(), mountOptions.join( ',' ) );
     if ( mount.isValid() )
     {
@@ -254,30 +252,25 @@ lookForFstabEntries( const QString& partitionPath )
 
         if ( fstabFile.open( QIODevice::ReadOnly | QIODevice::Text ) )
         {
-            const QStringList fstabLines = QString::fromLocal8Bit( fstabFile.readAll() ).split( '\n' );
-
-            for ( const QString& rawLine : fstabLines )
-            {
-                fstabEntries.append( FstabEntry::fromEtcFstab( rawLine ) );
-            }
+            const auto fstabLines = QString::fromLocal8Bit( fstabFile.readAll() ).split( '\n' );
             fstabFile.close();
-            const int lineCount = fstabEntries.count();
-            std::remove_if(
-                fstabEntries.begin(), fstabEntries.end(), []( const FstabEntry& x ) { return !x.isValid(); } );
-            cDebug() << Logger::SubEntry << "got" << fstabEntries.count() << "fstab entries from" << lineCount
+
+            const auto fstabEntries = Calamares::fromEtcFstabContents( fstabLines );
+            cDebug() << Logger::SubEntry << "got" << fstabEntries.count() << "fstab entries from" << fstabLines.count()
                      << "lines in" << fstabFile.fileName();
+            return fstabEntries;
         }
         else
         {
             cWarning() << "Could not read fstab from mounted fs";
+            return {};
         }
     }
     else
     {
         cWarning() << "Could not mount existing fs";
+        return {};
     }
-
-    return fstabEntries;
 }
 
 static QString
@@ -641,36 +634,3 @@ canonicalFilesystemName( const QString& fsName, FileSystem::Type* fsType )
 }
 
 }  // namespace PartUtils
-
-/* Implementation of methods for FstabEntry, from OsproberEntry.h */
-
-bool
-FstabEntry::isValid() const
-{
-    return !partitionNode.isEmpty() && !mountPoint.isEmpty() && !fsType.isEmpty();
-}
-
-FstabEntry
-FstabEntry::fromEtcFstab( const QString& rawLine )
-{
-    QString line = rawLine.simplified();
-    if ( line.startsWith( '#' ) )
-    {
-        return FstabEntry { QString(), QString(), QString(), QString(), 0, 0 };
-    }
-
-    QStringList splitLine = line.split( ' ' );
-    if ( splitLine.length() != 6 )
-    {
-        return FstabEntry { QString(), QString(), QString(), QString(), 0, 0 };
-    }
-
-    return FstabEntry {
-        splitLine.at( 0 ),  // path, or UUID, or LABEL, etc.
-        splitLine.at( 1 ),  // mount point
-        splitLine.at( 2 ),  // fs type
-        splitLine.at( 3 ),  // options
-        splitLine.at( 4 ).toInt(),  //dump
-        splitLine.at( 5 ).toInt()  //pass
-    };
-}
